@@ -12,11 +12,11 @@ Data::Text - Class to handle text in an OO way
 
 =head1 VERSION
 
-Version 0.08
+Version 0.09
 
 =cut
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 =head1 SYNOPSIS
 
@@ -28,6 +28,8 @@ Handle text in an OO way.
 
 Creates a Data::Text object.
 
+The optional parameter 'text' contains a string, or object, to initialise the object with.
+
 =cut
 
 sub new {
@@ -40,6 +42,12 @@ sub new {
 		return;
 	}
 
+	if(scalar(@_)) {
+		my $self = bless { }, $class;
+
+		return $self->set(@_);
+	}
+
 	return bless { }, $class;
 }
 
